@@ -9,11 +9,11 @@
 #' @param report logical: if \code{TRUE} the result of the test is reported at the \code{alpha} level.
 #'
 #' @return An object of the class \code{ITtest}, which is a list inducing following components:
-#' \item{pvalue.exact}{The calculated exact Monte Carlo p-value.}
-#' \item{pvalue.appro}{The asymptotic p-value.}
+#' \item{pvalue_exact}{The calculated exact Monte Carlo p-value.}
+#' \item{pvalue_appro}{The asymptotic p-value.}
 #' \item{statistic}{The value of the test statistic.}
 #' \item{Nsim}{The number of Monte Carlo samples that are used to estimate p-value.}
-#' \item{data.name}{The name of the input dataset.}
+#' \item{data_name}{The name of the input dataset.}
 #' \item{test}{The name of the test.}
 #' \item{Level}{The level of test.}
 #' \item{Result}{The result of the test at the alpha level with some descriptions on the type of significant interaction.}
@@ -34,10 +34,10 @@
 #'
 #' @examples
 #' data(MVGH)
-#' Piepho.test(MVGH, nsim = 1000)
+#' Piepho_test(MVGH, nsim = 1000)
 #'
 #' @export
-Piepho.test <- function(x, nsim = 10000, alpha = 0.05, report = TRUE) {
+Piepho_test <- function(x, nsim = 10000, alpha = 0.05, report = TRUE) {
   if (!is.matrix(x)) {
     stop("The input should be a matrix")
   } else {
@@ -46,14 +46,14 @@ Piepho.test <- function(x, nsim = 10000, alpha = 0.05, report = TRUE) {
     bl <- nrow(x)
     n <- tr * bl
     if (bl < 3) {
-      warning("Piepho.test needs at least 3 levels for the row factor")
-      str <- Result.Piepho(x, nsim = nsim, alpha = alpha, simu = NULL)
+      warning("Piepho_test needs at least 3 levels for the row factor")
+      str <- Result_Piepho(x, nsim = nsim, alpha = alpha, simu = NULL)
       out <- list(
-        pvalue.exact = NA,
-        pvalue.appro = NA,
+        pvalue_exact = NA,
+        pvalue_appro = NA,
         nsim = nsim,
         statistic = NA,
-        data.name = DNAME,
+        data_name = DNAME,
         test = "Piepho Test",
         Level = alpha,
         Result = str
@@ -70,19 +70,19 @@ Piepho.test <- function(x, nsim = 10000, alpha = 0.05, report = TRUE) {
       sigmahat <- (bl * (bl - 1) * W - sum(W)) / ((bl - 1) * (bl - 2) * (tr - 1))
       if (report) {
         if (pieph < alpha) {
-          str <- Result.Piepho(x, nsim = nsim, alpha = alpha, simu = simu)
+          str <- Result_Piepho(x, nsim = nsim, alpha = alpha, simu = simu)
         } else {
-          str <- paste("The Piepho.test could not detect any significant interaction.", "The estimated critical value of the Piepho.test with", nsim, "Monte Carlo samples is", round(qPiepho, 4), ".")
+          str <- paste0("The Piepho_test could not detect any significant interaction at the ", paste0(100 * (alpha), "%"), " level.", " The estimated critical value of the Piepho_test at the ", paste0(100 * (alpha), "%"), " level with ", nsim, " Monte Carlo samples is ", round(qPiepho, 4), ".")
         }
       } else {
         str <- paste("A report has not been wanted! To have a report, change argument 'report' to TRUE.")
       }
       out <- list(
-        pvalue.exact = pieph,
-        pvalue.appro = asypieph,
+        pvalue_exact = pieph,
+        pvalue_appro = asypieph,
         nsim = nsim,
         statistic = statistics,
-        data.name = DNAME,
+        data_name = DNAME,
         test = "Piepho Test",
         Level = alpha,
         Result = str
